@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.4 2001/06/04 05:14:23 darren Exp $ */
+/*	$Id: ClassModem.h,v 1.5 2002/02/02 20:03:09 darren Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -96,7 +96,8 @@ public:
 	ERROR	   = 5,		// error in dial command
 	FAILURE	   = 6,		// other problem (e.g. modem turned off)
 	NOFCON	   = 7,		// carrier established, but phase a failure
-	DATACONN   = 8		// data carrier established
+	DATACONN   = 8,		// data carrier established
+	RING	   = 9		// glare - ring detected after dial
     };
 
     enum {			// ClassModem::CallType
@@ -188,7 +189,7 @@ protected:
     fxStr	revQueryCmd;	// product revision identification command
 
     static const char* serviceNames[9];	 // class 2 services
-    static const char* callStatus[9];	 // printable call status
+    static const char* callStatus[10];	 // printable call status
     static const char* ATresponses[13];
 
     ClassModem(ModemServer&, const ModemConfig&);
