@@ -1,4 +1,4 @@
-/*	$Id: FaxModem.h,v 1.6 2001/02/05 06:32:57 darren Exp $ */
+/*	$Id: FaxModem.h,v 1.9 2001/12/15 23:47:23 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -150,7 +150,7 @@ public:
     enum {			// FaxModem::RTNHandling
         RTN_RETRANSMIT = 0,         // retransmit page after RTN until MCF/MPS
         RTN_GIVEUP     = 1,         // immediately abort
-        RTN_IGNORE     = 2,         // ignore error and send next page
+        RTN_IGNORE     = 2          // ignore error and send next page
     };
 
     virtual ~FaxModem();
