@@ -1,4 +1,4 @@
-/*	$Id: FaxRequest.h,v 1.3 2001/03/19 06:48:25 darren Exp $ */
+/*	$Id: FaxRequest.h,v 1.4 2002/02/15 04:20:48 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -87,7 +87,8 @@ public:
 	state_blocked	= 4,	// blocked by concurrent activity
 	state_ready	= 5,	// ready to be go, waiting for resources
 	state_active	= 6,	// actively being processed
-	state_done	= 7	// processing completed
+	state_done	= 7,	// processing completed with success
+	state_failed	= 8	// processing completed with a failure
     };
     struct stringval {		// string-valued item
 	const char* name;
